@@ -1,5 +1,6 @@
 #![allow(clippy::integer_arithmetic)]
-pub use solana_core::{cluster_info::MINIMUM_VALIDATOR_PORT_RANGE_WIDTH, test_validator};
+pub use solana_core::test_validator;
+pub use solana_gossip::cluster_info::MINIMUM_VALIDATOR_PORT_RANGE_WIDTH;
 use {
     console::style,
     indicatif::{ProgressDrawTarget, ProgressStyle},
@@ -60,7 +61,7 @@ pub fn redirect_stderr_to_file(logfile: Option<String>) -> Option<JoinHandle<()>
             #[cfg(not(unix))]
             {
                 println!("logging to a file is not supported on this platform");
-                ()
+                None
             }
         }
     };
